﻿################################################################################
# Following Parameters must be added to the VM Template for this script to work
# RootPassword
# CurrentRootPassword
################################################################################

. .\ExtensionsCommon.ps1

try 
{   
    # This script uses Standard functions provided by VConnect to connect to VCenter and to return results
    $connection = VConnect-Connect-VIServer -ErrorAction Stop
    $location = VConnect-GetLocation $Datacenter $Cluster $FolderName $RootFolderPath $ResourcePoolName $false

    if(!$location) 
    {
        return Get-ScriptErrorResult "VM Not Found at the given location" "VM Not Found"
    }

    $vm = $location | Get-VM -Name $VMName
    if(!$vm)
    {
        return Get-ScriptErrorResult "VM Not Found at the given location" "VM Not Found"
    }

    #
    # Also VM OS type can be checked like: $vm.Guest.GuestFamily -eq 'linuxGuest'
    #
    if($CurrentRootPassword -eq $null -or $RootPassword -eq $null)
    {
        return Get-ScriptResult -isSuccess $true -errorCode 0 -message "Skipped."
    }

    try 
    {   
        $update = "echo '" + $RootPassword +"' | passwd root --stdin"
        $vresult = Invoke-VMScript -VM $vm -ScriptText $update -GuestUser root -GuestPassword $CurrentRootPassword -scripttype bash
    }
    catch 
    {
        # Exception Ignored:
        # Exception is thrown after the Invoke-VMScript command successfully completes resetting the root user password. 
        # This is because of using root user to reset root users self password
    }

    # Validate that the new password has taken effect by running a sample command
    $test = "dir"
    $vresult2 = Invoke-VMScript -VM $vm -ScriptText $test -GuestUser root -GuestPassword $RootPassword -scripttype bash
    return Get-ScriptResult -isSuccess $true -errorCode 0 -message "Root Password Reset Success!"
}
catch 
{
    $errorMessage = $_.Exception.Message
    $exception = Get-FullLastError
    return Get-ScriptErrorResult $errorMessage $exception  
}